==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/shipping/item.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	item.lang.inc.php 2018-04-09 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_SHIPPING_ITEM_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, in welche ein Versand möglich sein soll. (z.B. AT,DE (lassen Sie dieses Feld leer, wenn Sie alle Zonen erlauben wollen))',
	'MODULE_SHIPPING_ITEM_ALLOWED_TITLE' => 'Erlaubte Versandzonen',
	'MODULE_SHIPPING_ITEM_COST_DESC' => 'Die Versandkosten werden mit der Anzahl an Artikel einer Bestellung multipliziert, wenn diese Versandart angegeben ist.',
	'MODULE_SHIPPING_ITEM_COST_TITLE' => 'Versandkosten',
	'MODULE_SHIPPING_ITEM_HANDLING_DESC' => 'Handling Gebühr für diese Versandart.',
	'MODULE_SHIPPING_ITEM_HANDLING_TITLE' => 'Handling Gebühr',
	'MODULE_SHIPPING_ITEM_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige',
	'MODULE_SHIPPING_ITEM_SORT_ORDER_TITLE' => 'Sortierreihenfolge',
	'MODULE_SHIPPING_ITEM_STATUS_DESC' => 'Möchten Sie Versandkosten pro Stück anbieten?',
	'MODULE_SHIPPING_ITEM_STATUS_TITLE' => 'Versandkosten pro Stück aktivieren',
	'MODULE_SHIPPING_ITEM_TAX_CLASS_DESC' => 'Folgende Steuerklasse an Versandkosten anwenden',
	'MODULE_SHIPPING_ITEM_TAX_CLASS_TITLE' => 'Steuerklasse',
	'MODULE_SHIPPING_ITEM_TEXT_DESCRIPTION' => 'Versandkosten pro Stück',
	'MODULE_SHIPPING_ITEM_TEXT_TITLE' => 'Versandkosten pro Stück',
	'MODULE_SHIPPING_ITEM_TEXT_WAY' => 'Standard',
	'MODULE_SHIPPING_ITEM_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, wird diese Versandmethode ausschließlich für diese Zone angewendet',
	'MODULE_SHIPPING_ITEM_ZONE_TITLE' => 'Versandzone'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/modules/shipping/item.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	item.lang.inc.php 2018-04-09 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_SHIPPING_ITEM_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, in welche ein Versand möglich sein soll. (z.B. AT,DE (lasse dieses Feld leer, wenn du alle Zonen erlauben willst))',
	'MODULE_SHIPPING_ITEM_ALLOWED_TITLE' => 'Erlaubte Versandzonen',
	'MODULE_SHIPPING_ITEM_COST_DESC' => 'Die Versandkosten werden mit der Anzahl an Artikel einer Bestellung multipliziert, wenn diese Versandart angegeben ist.',
	'MODULE_SHIPPING_ITEM_COST_TITLE' => 'Versandkosten',
	'MODULE_SHIPPING_ITEM_HANDLING_DESC' => 'Handling Gebühr für diese Versandart.',
	'MODULE_SHIPPING_ITEM_HANDLING_TITLE' => 'Handling Gebühr',
	'MODULE_SHIPPING_ITEM_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige',
	'MODULE_SHIPPING_ITEM_SORT_ORDER_TITLE' => 'Sortierreihenfolge',
	'MODULE_SHIPPING_ITEM_STATUS_DESC' => 'Möchtest du Versandkosten pro Stück anbieten?',
	'MODULE_SHIPPING_ITEM_STATUS_TITLE' => 'Versandkosten pro Stück aktivieren',
	'MODULE_SHIPPING_ITEM_TAX_CLASS_DESC' => 'Folgende Steuerklasse an Versandkosten anwenden',
	'MODULE_SHIPPING_ITEM_TAX_CLASS_TITLE' => 'Steuerklasse',
	'MODULE_SHIPPING_ITEM_TEXT_DESCRIPTION' => 'Versandkosten pro Stück',
	'MODULE_SHIPPING_ITEM_TEXT_TITLE' => 'Versandkosten pro Stück',
	'MODULE_SHIPPING_ITEM_TEXT_WAY' => 'Standard',
	'MODULE_SHIPPING_ITEM_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, wird diese Versandmethode ausschließlich für diese Zone angewendet',
	'MODULE_SHIPPING_ITEM_ZONE_TITLE' => 'Versandzone'
);
